@@ -1,23 +1,19 @@
 # Business::Shipping::Shipment::UPS
 # 
-# $Id: UPS.pm,v 1.4 2003/12/22 03:49:06 db-ship Exp $
+# $Id: UPS.pm,v 1.5 2004/01/21 22:39:54 db-ship Exp $
 # 
-# Copyright (c) 2003 Kavod Technologies, Dan Browning. All rights reserved. 
+# Copyright (c) 2003-2004 Kavod Technologies, Dan Browning. All rights reserved. 
 # 
 # Licensed under the GNU Public Licnese (GPL).  See COPYING for more info.
 # 
 
 package Business::Shipping::Shipment::UPS;
 
+$VERSION = do { my @r=(q$Revision: 1.5 $=~/\d+/g); sprintf "%d."."%03d"x$#r,@r };
+
 use strict;
 use warnings;
-
-use vars qw( $VERSION );
 use base( 'Business::Shipping::Shipment' );
-$VERSION = do { my @r=(q$Revision: 1.4 $=~/\d+/g); sprintf "%d."."%03d"x$#r,@r };
-
-use Business::Shipping::Package;
-
 use Business::Shipping::CustomMethodMaker
 	new_with_init => 'new',
 	new_hash_init => 'hash_init',
@@ -27,6 +23,9 @@ use Business::Shipping::CustomMethodMaker
 		required => [ 'from_zip' ],
 	];
 
+#
+# Why is this 'shipper' default needed for Shipping::Shipment::UPS?
+#
 use constant INSTANCE_DEFAULTS => (
 	shipper => 'UPS',
 );
