@@ -6,6 +6,7 @@ use diagnostics;
 
 use Business::Shipping;
 
+my $enable_online = 0;
 my $rate_request = Business::Shipping->rate_request( shipper => 'Offline::UPS' );
 
 $rate_request->submit(
@@ -28,6 +29,8 @@ $rate_request->submit(
 
 print "offline = " . $rate_request->total_charges() . "\n";
 
+exit unless $enable_online;
+
 my $rate_request_online = Business::Shipping->rate_request( shipper => 'Online::UPS' );
 
 $rate_request_online->submit(
